@@ -6,9 +6,10 @@ module Rabbit
     module ContainerElement
       extend Forwardable
 
-      include BlockElement
       include Enumerable
 
+      include Base
+
       attr_reader :elements
 
       def_delegators(:@elements, :empty?, :each, :first, :last)
