@@ -29,14 +29,19 @@ module Rabbit
           end
 
           widget.signal_connect("button_release_event") do |_widget, event|
-            handled = call_hook_procs(@button_release_hook_procs,
-                                      event, last_button_press_event)
-            if handled
-              clear_button_handler
+            if last_button_press_event
+              handled = call_hook_procs(@button_release_hook_procs,
+                                        event, last_button_press_event)
+              if handled
+                clear_button_handler
+              else
+                handled = handle_button_release(event, last_button_press_event)
+              end
+              handled
             else
-              handled = handle_button_release(event, last_button_press_event)
+              clear_button_handler
+              false
             end
-            handled
           end
         end
 
